<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>انقر على الأيقونة بالأسفل
أو اضغط على الاختصار مرة أخرى لإيقاف التسجيل</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>لا تقم بتدوير الشاشة أثناء التسجيل</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>جاري التسجيل</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>إلتقاط الشاشة</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>فشلت عملية الحفظ، نرجوا إجراء الحفظ في المجلد الرئيسي</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>انتهى التقاط الشاشة</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>اختر منطقة</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>تم حفظ 1%</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>حافظة</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>جاري حفظ ملف تسجيل الشاشة، الرجاء الانتظار...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>نظراً لتعطيل تأثير النافذة أثناء العملية، تم إيقاف التسجيل</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>فشلت عملية التقاط الشاشة</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>التصوير التمرير</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>إرفاق صور الشاشة</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>فتح المجلد</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>تم إتمام الصورة وتم نسخها إلى الحافظة</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>التراجع عن آخر إجراء</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>إرفاق صور الشاشة</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>جاري التسجيل</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>معاينة</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>انتهت عملية التسجيل</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>تم حفظ 1%</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>فتح المجلد</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>إلتقاط صورة الشاشة سيبدأ خلال 1 ثانية </translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>الحصول على مساعدة</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>فشل في التقاط لقطة شاشة مستمرة.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>وصلت إلى أسفل منطقة التمرير</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>تم الوصول إلى الحد الأقصى للطول</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ضبط منطقة الالتقاط</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>الرجاء القيام بتمرير عجلة الفأرة أو انقر لالتقاط لقطة شاشة قابلة للتمرير</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>إبطاء سرعة التمرير</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>المنطقة غير صالحة، انقر لـ</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>ادخل النص هنا</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>ابدء/لقطة شاشة</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>خروج/حفظ</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>تعديل الحجم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>اعدادات</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>بداية سريعة</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>تأخير لقطة الشاشة</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>لقطة شاشة كاملة</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>شكل بيضاوي</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>تراجع</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>زيادة الارتفاع</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>زيادة الانخفاض</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>زيادة العرض يساراً</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>زيادة العرض يميناً</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>تقليل الارتفاع</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>تقليل الانخفاض</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>تقليل العرض يساراً</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>تقليل العرض يميناً</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>اختصارات شاشة العرض</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>مفتاح التصوير</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>كامير الويب</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>بدء التسجيل</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>خيارات</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>بدء التسجيل</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>الفأرة</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>أدوات</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>استخراج النص</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>التصوير التمرير</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>إرفاق صور الشاشة</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>بدء تشغيل التعرف الضوئي على الحروف</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>بدء التصوير التمرير</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>سهم</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>مستطيل
اضغط واسمح للصيغة لرسم مربع</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>овал
اضغط واسمح للصيغة لرسم دائرة</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>فرشاة
اضغط واسمح للصيغة لرسم خط مستقيم</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>ضبط قوة التمويه (الرجاء التمرير لضبطها)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>ضبط حجم الفرشاة (الرجاء التمرير لضبطه)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>ضبط حجم النص (الرجاء التمرير لضبطه)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>انقر أو اسحب ل
اختيار المنطقة للتسجيل</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>عرض مفتاح التصوير (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>إخفاء مفتاح التصوير (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>عرض مفتاح التصوير (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>بدء تشغيل الكاميرا</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>إيقاف تشغيل الكاميرا</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>اعدادات</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>اعدادات</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>إطار في الثانية</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>كاميرا الويب</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>إطار في الثانية FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>ميكروفون</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>نظام الصوت</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>خيارات</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>إظهار المؤشر</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>إظهار النقرات</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>حفظ إلى</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>مقاطع</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>مستطيل (R)
اضغط واسمح للصيغة لرسم مربع</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>овал (O)
اضغط واسمح للصيغة لرسم دائرة</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>خط (L)
اضغط واسمح للصيغة لرسم خط عمودي أو أفقي</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>سهم (X)
اضغط واسمح للصيغة لرسم سهم عمودي أو أفقي</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>قلم الرصاص</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>التمويه</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>النص</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>التصوير التمرير (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>استخراج النص</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>إرفاق صور الشاشة (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>تراجع</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>حافظة</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>صور</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>مجلد</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>تعيين مسار عند الحفظ</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>تغيير المسار عند الحفظ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>تأثيرات الحدود</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>الظل</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>الحدود</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>استخراج النص</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>إغلاق</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>موافق</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>قم بتعديل منطقة التصوير داخل %1*%2 للحصول على تأثير فيديو أفضل</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>تسجيل الشاشة غير مدعوم في الوقت الحالي</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>تسجيل جديد</translation>
    </message>
</context>
</TS>
